ApplicationBuilder

Struct ApplicationBuilder 

pub struct ApplicationBuilder { /* private fields */ }
A Builder for Arcon Applications

ApplicationBuilder may be created through any type that implement the extension trait ToBuilderExt.

Usage

use arcon::prelude::*;
let mut builder: ApplicationBuilder = (0..100u64)
    .to_stream(|conf| conf.set_arcon_time(ArconTime::Process))
    .print()
    .builder();

let app: Application = builder.build();

Implementations

Source

impl ApplicationBuilder

pub fn name(&mut self, name: impl Into<String>) -> &mut Self

Sets the name of the application

pub fn config(&mut self, conf: ApplicationConf) -> &mut Self

Sets the configuration that is used during the build phase

pub fn build(&mut self) -> Application

Build an Arcon application

Note that this method only builds the application. In order to start it, see the following method.