pub struct ApplicationConf {Show 21 fields
pub execution_mode: ExecutionMode,
pub base_dir: PathBuf,
pub arcon_logger_type: LoggerType,
pub kompact_logger_type: LoggerType,
pub epoch_interval: u64,
pub watermark_interval: u64,
pub max_key: u64,
pub node_metrics_interval: u64,
pub buffer_pool_size: usize,
pub buffer_pool_limit: usize,
pub channel_batch_size: usize,
pub allocator_capacity: usize,
pub ctrl_system_host: Option<String>,
pub kompact_threads: usize,
pub kompact_throughput: usize,
pub kompact_msg_priority: f32,
pub kompact_network_host: Option<String>,
pub kompact_chunk_size: usize,
pub kompact_initial_chunk_count: usize,
pub kompact_max_chunk_count: usize,
pub kompact_encode_buf_min_free_space: usize,
}Expand description
Configuration for an Arcon Application
Fields
execution_mode: ExecutionModeEither a Local or Distributed Execution Mode
base_dir: PathBufBase directory for the application
arcon_logger_type: LoggerTypeLoggerType for arcon related logging
kompact_logger_type: LoggerTypeLoggerType for kompact related logging
epoch_interval: u64Generation interval in milliseconds for Epochs
watermark_interval: u64Generation interval in milliseconds for Watermarks at sources
max_key: u64The highest possible key value for a keyed stream
This should not be set too low or ridiculously high
node_metrics_interval: u64Interval in milliseconds for sending off metrics from nodes
buffer_pool_size: usizeAmount of buffers pre-allocated to a BufferPool
buffer_pool_limit: usizeA limit for amount of buffers in a BufferPool
channel_batch_size: usizeBatch size for channels
allocator_capacity: usizeMax amount of bytes allowed to be allocated by the Arcon Allocator
ctrl_system_host: Option<String>kompact_threads: usizeAmount of threads for Kompact’s threadpool
kompact_throughput: usizeControls the amount of messages a component processes per schedule iteration
kompact_msg_priority: f32Float value that sets message priority
kompact_network_host: Option<String>Host address for the KompactSystem
It is set as optional as it is not necessary for local deployments
kompact_chunk_size: usizekompact_initial_chunk_count: usizekompact_max_chunk_count: usizekompact_encode_buf_min_free_space: usizeImplementations
Sourceimpl ApplicationConf
impl ApplicationConf
pub fn state_dir(&self) -> PathBuf
pub fn checkpoints_dir(&self) -> PathBuf
pub fn arcon_logger(&self) -> ArconLogger
Sourcepub fn data_system_conf(&self) -> KompactConfig
pub fn data_system_conf(&self) -> KompactConfig
Returns a KompactConfig based on loaded ApplicationConf